@@ -1,7 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
- *  (C) 2012 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #include <stdio.h>
@@ -20,50 +19,55 @@
         }               \
     } while (0)
 
-MPI_Comm               comms[NUM_THREADS];
+MPI_Comm comms[NUM_THREADS];
 MTEST_THREAD_LOCK_TYPE comm_lock;
-int                    rank, size;
-int                    verbose = 0;
+int rank, size;
+int verbose = 0;
 
 MTEST_THREAD_RETURN_TYPE test_comm_dup(void *arg)
 {
     int rank;
     int i;
 
-    MPI_Comm_rank(comms[*(int*)arg], &rank);
+    MPI_Comm_rank(comms[*(int *) arg], &rank);
 
     for (i = 0; i < NUM_ITER; i++) {
-        MPI_Comm    comm, self_dup;
+        MPI_Comm comm, self_dup;
 
-        if (*(int*)arg == rank) {
+        if (*(int *) arg == rank) {
             MTestSleep(1);
         }
 
         MTest_thread_lock(&comm_lock);
-        if (verbose) printf("%d: Thread %d - Comm_dup %d start\n", rank, *(int*)arg, i);
+        if (verbose)
+            printf("%d: Thread %d - Comm_dup %d start\n", rank, *(int *) arg, i);
         MPI_Comm_dup(MPI_COMM_SELF, &self_dup);
-        if (verbose) printf("%d: Thread %d - Comm_dup %d finish\n", rank, *(int*)arg, i);
+        if (verbose)
+            printf("%d: Thread %d - Comm_dup %d finish\n", rank, *(int *) arg, i);
         MTest_thread_unlock(&comm_lock);
 
         MPI_Comm_free(&self_dup);
 
-        if (verbose) printf("%d: Thread %d - comm_dup %d start\n", rank, *(int*)arg, i);
-        MPI_Comm_dup(comms[*(int*)arg], &comm);
+        if (verbose)
+            printf("%d: Thread %d - comm_dup %d start\n", rank, *(int *) arg, i);
+        MPI_Comm_dup(comms[*(int *) arg], &comm);
         MPI_Comm_free(&comm);
-        if (verbose) printf("%d: Thread %d - comm_dup %d finish\n", rank, *(int*)arg, i);
+        if (verbose)
+            printf("%d: Thread %d - comm_dup %d finish\n", rank, *(int *) arg, i);
     }
 
-    if (verbose) printf("%d: Thread %d - Done.\n", rank, *(int*)arg);
-    return (MTEST_THREAD_RETURN_TYPE)0;
+    if (verbose)
+        printf("%d: Thread %d - Done.\n", rank, *(int *) arg);
+    return (MTEST_THREAD_RETURN_TYPE) 0;
 }
 
 
 int main(int argc, char **argv)
 {
-    int         thread_args[NUM_THREADS];
-    int         i, provided;
+    int thread_args[NUM_THREADS];
+    int i, provided;
 
-    MPI_Init_thread(&argc, &argv, MPI_THREAD_MULTIPLE, &provided);
+    MTest_Init_thread(&argc, &argv, MPI_THREAD_MULTIPLE, &provided);
 
     check(provided == MPI_THREAD_MULTIPLE);
 
@@ -78,7 +82,7 @@ int main(int argc, char **argv)
 
     for (i = 0; i < NUM_THREADS; i++) {
         thread_args[i] = i;
-        MTest_Start_thread( test_comm_dup, (void *)&thread_args[i] );
+        MTest_Start_thread(test_comm_dup, (void *) &thread_args[i]);
     }
 
     MTest_Join_threads();
@@ -87,10 +91,7 @@ int main(int argc, char **argv)
         MPI_Comm_free(&comms[i]);
     }
 
-    if (rank == 0)
-        printf(" No Errors\n");
-
-    MPI_Finalize();
+    MTest_Finalize(0);
 
     return 0;
 }
